.. _user_guide_multi_column_index:

Multi-column operations
========================

Skrub provides various tools to extend the use of single column transformers to
multiple columns.

.. include:: includes/big_toc_css.rst

.. toctree::
   :maxdepth: 3

   modules/multi_column_operations/multi_column_operations
   modules/multi_column_operations/drop_uninformative
   modules/multi_column_operations/selectors
   modules/multi_column_operations/type_of_selectors
   modules/multi_column_operations/advanced_selectors
